@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: sftp_fs_memory.c,v 1.13 2002/05/13 06:55:34 priikone Exp $ */
+/* $Id: sftp_fs_memory.c,v 1.14 2002/09/07 10:59:54 priikone Exp $ */
 /* XXX TODO Win32 support */
 
 #include "silcincludes.h"
@@ -1074,7 +1074,7 @@ void mem_realpath(void *context, SilcSFTP sftp,
     goto fail;
   name->count = 1;
 
-  (*callback)(sftp, SILC_SFTP_STATUS_FAILURE, (const SilcSFTPName)name, 
+  (*callback)(sftp, SILC_SFTP_STATUS_OK, (const SilcSFTPName)name, 
 	      callback_context);
 
   silc_sftp_name_free(name);
