@@ -63,9 +63,10 @@ typedef struct {
 typedef struct SilcServerCommandPendingStruct {
   SilcServer server;
   SilcCommand reply_cmd;
+  SilcUInt16 ident;
+  unsigned int reply_check : 8;
   SilcCommandCb callback;
   void *context;
-  SilcUInt16 ident;
   struct SilcServerCommandPendingStruct *next;
 } SilcServerCommandPending;
 
@@ -130,24 +131,25 @@ SILC_SERVER_CMD_FUNC(invite);
 SILC_SERVER_CMD_FUNC(quit);
 SILC_SERVER_CMD_FUNC(kill);
 SILC_SERVER_CMD_FUNC(info);
-SILC_SERVER_CMD_FUNC(connect);
+SILC_SERVER_CMD_FUNC(stats);
 SILC_SERVER_CMD_FUNC(ping);
 SILC_SERVER_CMD_FUNC(oper);
-SILC_SERVER_CMD_FUNC(pass);
-SILC_SERVER_CMD_FUNC(admin);
 SILC_SERVER_CMD_FUNC(join);
 SILC_SERVER_CMD_FUNC(motd);
 SILC_SERVER_CMD_FUNC(umode);
 SILC_SERVER_CMD_FUNC(cmode);
 SILC_SERVER_CMD_FUNC(cumode);
 SILC_SERVER_CMD_FUNC(kick);
-SILC_SERVER_CMD_FUNC(ignore);
 SILC_SERVER_CMD_FUNC(ban);
-SILC_SERVER_CMD_FUNC(close);
-SILC_SERVER_CMD_FUNC(shutdown);
+SILC_SERVER_CMD_FUNC(detach);
+SILC_SERVER_CMD_FUNC(watch);
 SILC_SERVER_CMD_FUNC(silcoper);
 SILC_SERVER_CMD_FUNC(leave);
 SILC_SERVER_CMD_FUNC(users);
 SILC_SERVER_CMD_FUNC(getkey);
 
+SILC_SERVER_CMD_FUNC(connect);
+SILC_SERVER_CMD_FUNC(close);
+SILC_SERVER_CMD_FUNC(shutdown);
+
 #endif
