@@ -17,7 +17,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: serverconfig.c,v 1.59 2002/06/25 21:43:19 priikone Exp $ */
+/* $Id: serverconfig.c,v 1.62 2002/09/07 20:33:59 priikone Exp $ */
 
 #include "serverincludes.h"
 #include "server_internal.h"
@@ -545,7 +545,10 @@ SILC_CONFIG_CALLBACK(fetch_logging)
 {
   SILC_SERVER_CONFIG_SECTION_INIT(SilcServerConfigLogging);
 
-  if (!strcmp(name, "quicklogs")) {
+  if (!strcmp(name, "timestamp")) {
+    config->logging_timestamp = *(bool *)val;
+  }
+  else if (!strcmp(name, "quicklogs")) {
     config->logging_quick = *(bool *)val;
   }
   else if (!strcmp(name, "flushdelay")) {
@@ -668,6 +671,9 @@ SILC_CONFIG_CALLBACK(fetch_connparam)
     tmp->version_software_vendor =
       (*(char *)val ? strdup((char *) val) : NULL);
   }
+  else if (!strcmp(name, "anonymous")) {
+    tmp->anonymous = *(bool *)val;
+  }
   else
     return SILC_CONFIG_EINTERNAL;
 
@@ -1081,6 +1087,7 @@ static const SilcConfigTable table_logging_c[] = {
 };
 
 static const SilcConfigTable table_logging[] = {
+  { "timestamp",	SILC_CONFIG_ARG_TOGGLE,	fetch_logging,	NULL },
   { "quicklogs",	SILC_CONFIG_ARG_TOGGLE,	fetch_logging,	NULL },
   { "flushdelay",	SILC_CONFIG_ARG_INT,	fetch_logging,	NULL },
   { "info",		SILC_CONFIG_ARG_BLOCK,	fetch_logging,	table_logging_c },
@@ -1104,7 +1111,8 @@ static const SilcConfigTable table_connparam[] = {
   { "key_exchange_pfs",	       SILC_CONFIG_ARG_TOGGLE, fetch_connparam,	NULL },
   { "version_protocol",	       SILC_CONFIG_ARG_STR,    fetch_connparam,	NULL },
   { "version_software",	       SILC_CONFIG_ARG_STR,    fetch_connparam,	NULL },
-  { "version_software_vendor", SILC_CONFIG_ARG_STR,     fetch_connparam,	NULL },
+  { "version_software_vendor", SILC_CONFIG_ARG_STR,    fetch_connparam,	NULL },
+  { "anonymous",               SILC_CONFIG_ARG_TOGGLE, fetch_connparam,	NULL },
   { 0, 0, 0, 0 }
 };
 
@@ -1208,6 +1216,9 @@ SilcServerConfig silc_server_config_alloc(const char *filename)
   if (!config_new)
     return NULL;
 
+  /* general config defaults */
+  config_new->logging_timestamp = TRUE;
+
   /* obtain a config file object */
   file = silc_config_open(filename);
   if (!file) {
@@ -1665,6 +1676,7 @@ void silc_server_config_setlogfiles(SilcServer server)
 
   SILC_LOG_DEBUG(("Setting configured log file names and options"));
 
+  silc_log_timestamp = config->logging_timestamp;
   silc_log_quick = config->logging_quick;
   silc_log_flushdelay = (config->logging_flushdelay ?
 			 config->logging_flushdelay :
@@ -1811,6 +1823,31 @@ silc_server_config_find_router_conn(SilcServer server, char *host, int port)
   return serv;
 }
 
+/* Find backup router connection by host (name or ip) */
+
+SilcServerConfigRouter *
+silc_server_config_find_backup_conn(SilcServer server, char *host)
+{
+  SilcServerConfig config = server->config;
+  SilcServerConfigRouter *serv = NULL;
+
+  if (!host)
+    return NULL;
+
+  if (!config->routers)
+    return NULL;
+
+  for (serv = config->routers; serv; serv = serv->next) {
+    if (!serv->backup_router)
+      continue;
+    if (!silc_string_compare(serv->host, host))
+      continue;
+    break;
+  }
+
+  return serv;
+}
+
 /* Returns TRUE if configuration for a router connection that we are
    initiating exists. */
 
